# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API WebDAVHTTPMethod <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7>`_
"""

CONNECT: 'uno.Enum'
"""
HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
COPY: 'uno.Enum'
"""
Copy the source to the target folder.

WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
"""
DELETE: 'uno.Enum'
"""
HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
GET: 'uno.Enum'
"""
Get a list of all folders.

HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
HEAD: 'uno.Enum'
"""
HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
LOCK: 'uno.Enum'
"""
WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
"""
MKCOL: 'uno.Enum'
"""
WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
"""
MOVE: 'uno.Enum'
"""
Move the source to the target folder.

WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
"""
OPTIONS: 'uno.Enum'
"""
HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
PATCH: 'uno.Enum'
"""
HTTP request method as defined in RFC 5789: PATCH Method for HTTP
"""
POST: 'uno.Enum'
"""
HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
PROPFIND: 'uno.Enum'
"""
WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
"""
PROPPATCH: 'uno.Enum'
"""
WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
"""
PUT: 'uno.Enum'
"""
HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
TRACE: 'uno.Enum'
"""
HTTP request method as defined in RFC 2616: Hypertext Transfer Protocol – HTTP/1.1
"""
UNLOCK: 'uno.Enum'
"""
WebDAV methods as defined in HTTP Extensions for Web Distributed Authoring and Versioning (WebDAV)
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XRowSetListener(XEventListener_c7230c4a):
    """
    is used for receiving \"cursorMoved\", \"rowChanged\", and \"rowSetChanged\" events posted by, for example, a row set.

    See Also:
        `API XRowSetListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XRowSetListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XRowSetListener']

    def cursorMoved(self, event: 'EventObject_a3d70b03') -> None:
        """
        is called when a row set's cursor is moved.
        """
    def rowChanged(self, event: 'EventObject_a3d70b03') -> None:
        """
        is called when a row is inserted, updated, or deleted.
        """
    def rowSetChanged(self, event: 'EventObject_a3d70b03') -> None:
        """
        is called when the row set has changed, or in other words, when the row set has been reexecuted.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.document
from typing_extensions import Literal
"""
Const

Specify the way a document can be updated.

**since**

    OOo 1.1.2

See Also:
    `API UpdateDocMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1document_1_1UpdateDocMode.html>`_
"""
NO_UPDATE: Literal[0]
"""
Do not update document.
"""
QUIET_UPDATE: Literal[1]
"""
Update document if it does not require a dialog.

Otherwise do not update. For example a link to a database can require a dialog to get password for an update.
"""
ACCORDING_TO_CONFIG: Literal[2]
"""
Produce update according to configuration settings.

If there are no settings use dialog.
"""
FULL_UPDATE: Literal[3]
"""
Update document even if it does require a dialog.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Offsets into the sequence of strings returned by XLocaleData.getReservedWord().

See Also:
    `API reservedWords <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1reservedWords.html>`_
"""
TRUE_WORD: Literal[0]
"""
\"true\"
"""
FALSE_WORD: Literal[1]
"""
\"false\"
"""
QUARTER1_WORD: Literal[2]
"""
\"1st quarter\"
"""
QUARTER2_WORD: Literal[3]
"""
\"2nd quarter\"
"""
QUARTER3_WORD: Literal[4]
"""
\"3rd quarter\"
"""
QUARTER4_WORD: Literal[5]
"""
\"4th quarter\"
"""
ABOVE_WORD: Literal[6]
"""
\"above\"
"""
BELOW_WORD: Literal[7]
"""
\"below\"
"""
QUARTER1_ABBREVIATION: Literal[8]
"""
\"Q1\"
"""
QUARTER2_ABBREVIATION: Literal[9]
"""
\"Q2\"
"""
QUARTER3_ABBREVIATION: Literal[10]
"""
\"Q3\"
"""
QUARTER4_ABBREVIATION: Literal[11]
"""
\"Q4\"
"""
COUNT: Literal[12]
"""
Yes, this must be the count of known reserved words and one more than the maximum number used above! Count of known reserved words.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.3
from .x_introspection import XIntrospection as XIntrospection_d5510cda


class theIntrospection(XIntrospection_d5510cda):
    """
    Singleton Class

    provides functionality to get information about an object's properties and methods.
    
    Important note:An object can only be inspected completely if it supports the com.sun.star.lang.XTypeProvider interface.
    
    For details, see method XIntrospection.inspect().
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theIntrospection <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1beans_1_1theIntrospection.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form.binding
# Libre Office Version: 7.3
from typing_extensions import Literal
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ListEntryEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies the event which is notified when a change in a string entry list occurred

    See Also:
        `API ListEntryEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1form_1_1binding_1_1ListEntryEvent.html>`_
    """
    typeName: Literal['com.sun.star.form.binding.ListEntryEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Entries: typing.Optional[typing.Tuple[str, ...]] = ..., Position: typing.Optional[int] = ..., Count: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Entries (typing.Tuple[str, ...], optional): Entries value.
            Position (int, optional): Position value.
            Count (int, optional): Count value.
        """


    @property
    def Entries(self) -> typing.Tuple[str, ...]:
        """
        denotes the changed entries
        
        The concrete semantics of the value depends on the concrete event being notified.
        """


    @property
    def Position(self) -> int:
        """
        denotes the position where a change occurred.
        
        The concrete semantics of the value depends on the concrete event being notified.
        """


    @property
    def Count(self) -> int:
        """
        denotes the number of changed entries, in case a change of an entry range is being notified.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..style.graphic_location import GraphicLocation as GraphicLocation_e3ef0d30
    from ..table.border_line import BorderLine as BorderLine_a3f80af6
    from .x_text import XText as XText_690408ca
    from .x_text_section import XTextSection as XTextSection_b1730b9f
    from ..util.color import Color as Color_68e908c5

class CellProperties(UserDefinedAttributesSupplier_9fbe1222, XPropertySet_bc180bfa):
    """
    Service Class

    service that holds all cell properties of a text table cell in a text document.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API CellProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html>`_
    """
    @property
    def BackColor(self) -> 'Color_68e908c5':
        """
        contains the background color.
        """
    @property
    def BackGraphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the graphic object that is displayed as background graphic.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def BackGraphicFilter(self) -> str:
        """
        contains the name of the graphic filter of the background graphic.
        """
    @property
    def BackGraphicLocation(self) -> 'GraphicLocation_e3ef0d30':
        """
        determines the position of the background graphic.
        """
    @property
    def BackGraphicURL(self) -> str:
        """
        contains the URL to the background graphic.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
    @property
    def BackTransparent(self) -> bool:
        """
        determines whether the background is transparent.
        """
    @property
    def BottomBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the bottom border line.
        """
    @property
    def BottomBorderDistance(self) -> int:
        """
        contains the distance of the bottom border.
        """
    @property
    def CellName(self) -> str:
        """
        contains the cell name, see SwXTextTable.getCellByName for more information
        """
    @property
    def IsProtected(self) -> bool:
        """
        determines whether the cell is write protected or not.
        """
    @property
    def LeftBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the left border line.
        """
    @property
    def LeftBorderDistance(self) -> int:
        """
        contains the distance of the left border.
        """
    @property
    def NumberFormat(self) -> int:
        """
        contains the number format.
        """
    @property
    def ParentText(self) -> 'XText_690408ca':
        """
        Parent text of this table cell.
        
        This might be a header text, body text, parent cell, etc.
        
        **since**
        
            LibreOffice 6.3
        """
    @property
    def RightBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the right border line.
        """
    @property
    def RightBorderDistance(self) -> int:
        """
        contains the distance of the right border.
        """
    @property
    def TextSection(self) -> 'XTextSection_b1730b9f':
        """
        contains the text section the text table is contained in if there is any.
        """
    @property
    def TopBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the top border line.
        """
    @property
    def TopBorderDistance(self) -> int:
        """
        contains the distance of the top border.
        """
    @property
    def VertOrient(self) -> int:
        """
        the vertical orientation of the text inside of the table cells in this row.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XFormControllerListener(XEventListener_c7230c4a):
    """
    allows to be notified when the activation status of a FormController changes.
    
    A form controller is activated if a form control gains the focus and none of its controls currently owned the focus before.

    See Also:
        `API XFormControllerListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XFormControllerListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XFormControllerListener']

    def formActivated(self, rEvent: 'EventObject_a3d70b03') -> None:
        """
        is invoked when a control of the controller gained the focus and the controller was not previously activated.
        """
    def formDeactivated(self, rEvent: 'EventObject_a3d70b03') -> None:
        """
        is invoked when a control of the \"XFormController\" lost the focus and no control of the controller received the focus.
        
        In other words, no control of the controller owns the focus.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.graphic
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_primitive2_d import XPrimitive2D as XPrimitive2D_d5730c6d
    from ..util.x_binary_data_container import XBinaryDataContainer as XBinaryDataContainer_19270ea0

class XPdfDecomposer(XInterface_8f010a43):
    """
    XPdfDecomposer interface.
    
    This renders a PDF data into a bitmap and returns it as a primitive.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API XPdfDecomposer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1graphic_1_1XPdfDecomposer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.graphic.XPdfDecomposer']

    def getDecomposition(self, xDataContainer: 'XBinaryDataContainer_19270ea0', xDecompositionParameters: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'typing.Tuple[XPrimitive2D_d5730c6d, ...]':
        """
        Retrieve decomposed list - in this case a bitmap with the rendered PDF.
        
        sal_Int32 PageIndex - which page to use
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from ..awt.uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c

class ColumnDescriptorControlModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a ColumnDescriptorControl.

    See Also:
        `API ColumnDescriptorControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnDescriptorControlModel.html>`_
    """
    @property
    def ActiveConnection(self) -> 'XConnection_a36a0b0c':
        """
        specifies the connection to a database.
        """
    @property
    def Border(self) -> int:
        """
        specifies the border style of the control.
        """
    @property
    def Column(self) -> 'XPropertySet_bc180bfa':
        """
        specifies the column descriptor where the values will be stored in.
        """
    @property
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
    @property
    def Tabstop(self) -> bool:
        """
        specifies that the control can be reached with the TAB key.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..task.classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest_9f72121b
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from ..ucb.x_content import XContent as XContent_79db0975

class DocumentSaveRequest(ClassifiedInteractionRequest_9f72121b):
    """
    Exception Class

    an error specifying the lack of a document name
    
    Usually thrown if someone tries to save a document which hasn't a name yet.
    
    **since**
    
        OOo 2.0

    See Also:
        `API DocumentSaveRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1sdb_1_1DocumentSaveRequest.html>`_
    """

    typeName: Literal['com.sun.star.sdb.DocumentSaveRequest']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., Classification: typing.Optional[InteractionClassification_6c4d10e7] = ..., Content: typing.Optional[XContent_79db0975] = ..., Name: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            Content (XContent, optional): Content value.
            Name (str, optional): Name value.
        """
    @property
    def Content(self) -> XContent_79db0975:
        """
        specifies the content where the document should save inside.
        
        Somebody handling the request could, e.g., use the content as root content to display the hierarchy of the sub contents.
        """

    @property
    def Name(self) -> str:
        """
        The default name of the document, may be empty.
        """


__all__ = ['DocumentSaveRequest']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class XFontMappingUseItem(object):
    """
    Struct Class

    Information about a font mapping that took place.
    
    **since**
    
        LibreOffice 7.3

    See Also:
        `API XFontMappingUseItem <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1XFontMappingUseItem.html>`_
    """
    typeName: Literal['com.sun.star.awt.XFontMappingUseItem']

    def __init__(self, usedFonts: typing.Optional[typing.Tuple[str, ...]] = ..., originalFont: typing.Optional[str] = ..., count: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            usedFonts (typing.Tuple[str, ...], optional): usedFonts value.
            originalFont (str, optional): originalFont value.
            count (int, optional): count value.
        """


    @property
    def usedFonts(self) -> typing.Tuple[str, ...]:
        """
        A list of fonts that were actually used, in their order.
        
        Each font is identified as family name or 'familyName/styleName' (if style name is not empty).
        """


    @property
    def originalFont(self) -> str:
        """
        The family name or 'familyName/styleName' (if style name is not empty) of the requested font.
        """


    @property
    def count(self) -> int:
        """
        The number of times this mapping took place.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from .x_supported_locales import XSupportedLocales as XSupportedLocales_5bda1056
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_hyphenated_word import XHyphenatedWord as XHyphenatedWord_3a880f73
    from .x_possible_hyphens import XPossibleHyphens as XPossibleHyphens_4aa50fed

class XHyphenator(XSupportedLocales_5bda1056):
    """
    provides functionality for hyphenation of single words.
    
    Its three main functionalities are to provide a suitable position for breaking lines within a word, query about the existence of an alternative spelling at a specific position of a word and provide a list of possible hyphenation positions within a word.
    
    A hyphenation position for a word with n characters is represented by a value in the range from 0 to n-2, indicating the position of the character after which the hyphenation is done. That is, it is after the first and before the last character.
    
    A valid hyphenation position is a hyphenation position that fulfills all the restrictions implied by the properties MinLeading, MinTrailing and MinWordLength.

    See Also:
        `API XHyphenator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XHyphenator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XHyphenator']

    def createPossibleHyphens(self, aWord: str, aLocale: 'Locale_70d308fa', aProperties: 'PropertyValues_d6470ce6') -> 'XPossibleHyphens_4aa50fed':
        """
        returns information about all possible hyphenation positions of a word.
        
        If the language is not supported, an IllegalArgumentException exception is raised.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def hyphenate(self, aWord: str, aLocale: 'Locale_70d308fa', nMaxLeading: int, aProperties: 'PropertyValues_d6470ce6') -> 'XHyphenatedWord_3a880f73':
        """
        tries to find a valid hyphenation position relative to the beginning of a word.
        
        Note: Some languages, for example Arabic, are written from right to left.
        
        If the language is not supported, an IllegalArgumentException exception is raised.
        
        It has to be greater than or equal to 0.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def queryAlternativeSpelling(self, aWord: str, aLocale: 'Locale_70d308fa', nIndex: int, aProperties: 'PropertyValues_d6470ce6') -> 'XHyphenatedWord_3a880f73':
        """
        checks whether hyphenation at a position in a word will result in an alternative spelling or not.
        
        An alternative spelling position is a hyphen position where, if hyphenation is done here, the writing of the word changes. Example: \"B&auml;cker\" in German pre spelling-reform becomes \"B&auml;kker\" if hyphenation is done after the \"c\".
        
        The hyphenation position does not need to be a valid one to be an alternative spelling position.
        
        If the language is not supported, an IllegalArgumentException exception is raised.
        
        If the length of the word is n, the value of this parameter has to be in the range from 0 to n-2.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XStringWidth(XInterface_8f010a43):
    """
    An interface that encapsulates the abstract notion of string width.

    See Also:
        `API XStringWidth <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XStringWidth.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XStringWidth']

    def queryStringWidth(self, aString: str) -> int:
        """
        compute the width of a given string.
        
        Depending on the implementation of this interface, the width of a string can be rather different things, like the number of characters in the string, or the width in pixel when displayed with a specific font.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt.tab
from typing_extensions import Literal
import typing
from ...container.x_container import XContainer as XContainer_d6fb0cc6
from ...container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
if typing.TYPE_CHECKING:
    from .x_tab_page_model import XTabPageModel as XTabPageModel_dcde0c96

class XTabPageContainerModel(XContainer_d6fb0cc6, XIndexContainer_1c040ebe):
    """
    specifies an interface for a UnoControlTabPageContainerModel.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XTabPageContainerModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.tab.XTabPageContainerModel']

    def createTabPage(self, TabPageID: int) -> 'XTabPageModel_dcde0c96':
        """
        creates a TabPageModel which can be inserted into the container.
        """
    def loadTabPage(self, TabPageID: int, ResourceURL: str) -> 'XTabPageModel_dcde0c96':
        """
        creates a TabPageModel which can be inserted into the container, by loading it from a user interface resource file.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class DataPilotTablePositionData(object):
    """
    Struct Class

    This structure contains information on a cell within a DataPilot table.
    
    This structure contains information on a particular cell within a DataPilot table, and is used to retrieve its metadata. The PositionType member specifies in which sub-area of the table the cell is positioned, which in turn determines the type of metadata contained in the PositionData member.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotTablePositionData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionData.html>`_
    """
    typeName: Literal['com.sun.star.sheet.DataPilotTablePositionData']

    def __init__(self, PositionType: typing.Optional[int] = ..., PositionData: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            PositionType (int, optional): PositionType value.
            PositionData (object, optional): PositionData value.
        """


    @property
    def PositionType(self) -> int:
        """
        This parameter specifies which sub-area of a DataPilot table a given cell is positioned.
        
        See DataPilotTablePositionType for how to interpret the value of this parameter.
        """


    @property
    def PositionData(self) -> object:
        """
        This member contains a structure of different types depending on the position type specified in PositionType member.
        
        When the value of PositionType is DataPilotTablePositionType.RESULT, DataPilotTablePositionData.PositionData contains an instance of type DataPilotTableResultData, whereas when the value of DataPilotTablePositionData.PositionType is either DataPilotTablePositionType.ROW_HEADER or DataPilotTablePositionType.COLUMN_HEADER, then the PositionData member contains an instance of type DataPilotTableHeaderData.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class Ambiguous(object):
    """
    Struct Class

    A value of a given type that can be ambiguous.
    
    This structure is used as the type of interface attributes corresponding to instances of com.sun.star.beans.Property that have the com.sun.star.beans.PropertyAttribute.MAYBEAMBIGUOUS.

    See Also:
        `API Ambiguous <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1Ambiguous_3_01T_01_4.html>`_
    """
    typeName: Literal['com.sun.star.beans.Ambiguous']

    def __init__(self, Value: typing.Optional[object] = ..., IsAmbiguous: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Value (object, optional): Value value.
            IsAmbiguous (bool, optional): IsAmbiguous value.
        """


    @property
    def Value(self) -> object:
        """
        The underlying value of this structure instance.
        
        Even if this structure instance is ambiguous, this member should contain a useful value. If there is no useful value for an ambiguous structure instance, com.sun.star.beans.Optional can be used as the type of this member.
        """


    @property
    def IsAmbiguous(self) -> bool:
        """
        Marks this structure instance as ambiguous.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.registry
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API RegistryValueType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1registry.html#a62fb96939bafde3da828f782a8433ac3>`_
"""

ASCII: 'uno.Enum'
"""
the type of the key is ASCII.
"""
ASCIILIST: 'uno.Enum'
"""
the type of the key is an ASCIILIST.
"""
BINARY: 'uno.Enum'
"""
the type of the key is binary.
"""
LONG: 'uno.Enum'
"""
the type of the key is long.
"""
LONGLIST: 'uno.Enum'
"""
the type of the key is LONGLIST.
"""
NOT_DEFINED: 'uno.Enum'
"""
the type of the key is not defined.
"""
STRING: 'uno.Enum'
"""
the type of the key is a string.
"""
STRINGLIST: 'uno.Enum'
"""
the type of the key is a STRINGLIST.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
import typing
from .x_text_field import XTextField as XTextField_9a630aae
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XDependentTextField(XTextField_9a630aae):
    """
    makes it possible to attach this TextField to a TextFieldMaster.

    See Also:
        `API XDependentTextField <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XDependentTextField.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XDependentTextField']

    def attachTextFieldMaster(self, xFieldMaster: 'XPropertySet_bc180bfa') -> None:
        """
        method must be called to attach the TextFieldMaster to this TextField.
        
        A TextFieldMaster can only be assigned once.
        
        Example: Create and insert a user field (with a UserField):

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getTextFieldMaster(self) -> 'XPropertySet_bc180bfa':
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .point import Point as Point_5fb2085e
    from .size import Size as Size_576707ef

class XUnitConversion(XInterface_8f010a43):
    """
    allows converting between different measurement units
    
    **since**
    
        OOo 3.0

    See Also:
        `API XUnitConversion <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XUnitConversion.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XUnitConversion']

    def convertPointToLogic(self, Point: 'Point_5fb2085e', TargetUnit: int) -> 'Point_5fb2085e':
        """
        converts the given Point, which is specified in pixels, into the given logical unit

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertPointToPixel(self, Point: 'Point_5fb2085e', SourceUnit: int) -> 'Point_5fb2085e':
        """
        converts the given Point, which is specified in the given logical unit, into pixels

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertSizeToLogic(self, Size: 'Size_576707ef', TargetUnit: int) -> 'Size_576707ef':
        """
        converts the given Size, which is specified in pixels, into the given logical unit

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertSizeToPixel(self, Size: 'Size_576707ef', SourceUnit: int) -> 'Size_576707ef':
        """
        converts the given Size, which is specified in the given logical unit, into pixels

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xsd
import typing
from .x_data_type import XDataType as XDataType_83f209cb
if typing.TYPE_CHECKING:
    from ..util.date import Date as Date_60040844

class Date(XDataType_83f209cb):
    """
    Service Class

    specifies an XSD compliant date type

    See Also:
        `API Date <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xsd_1_1Date.html>`_
    """
    @property
    def MaxExclusiveDate(self) -> 'Date_60040844':
        """
        specifies the exclusive upper bound for the value
        """
    @property
    def MaxInclusiveDate(self) -> 'Date_60040844':
        """
        specifies the inclusive upper bound for the value
        """
    @property
    def MinExclusiveDate(self) -> 'Date_60040844':
        """
        specifies the exclusive lower bound for the value
        """
    @property
    def MinInclusiveDate(self) -> 'Date_60040844':
        """
        specifies the inclusive lower bound for the value
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_scaling import XScaling as XScaling_97500a65
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class XRegressionCurveCalculator(XInterface_8f010a43):
    """

    See Also:
        `API XRegressionCurveCalculator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XRegressionCurveCalculator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.XRegressionCurveCalculator']

    def getCorrelationCoefficient(self) -> float:
        """
        Returns the value of the correlation coefficient for the given regression.
        
        This value is often denoted as r or R.
        
        The value of r is signed. Often r2 is used instead of r to denote a regression curve's accuracy.
        """
    def getCurveValue(self, x: float) -> float:
        """
        calculates the value of the regression curve for x.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getCurveValues(self, min: float, max: float, nPointCount: int, xScalingX: 'XScaling_97500a65', xScalingY: 'XScaling_97500a65', bMaySkipPointsInCalculation: bool) -> 'typing.Tuple[RealPoint2D_d6e70c78, ...]':
        """
        calculate multiple points of a regression curve at once.
        
        Note that this method may optimize the output by returning less points, e.g. for a line you may get only two resulting points instead of nPointCount() points. This is only allowed if the parameter bMaySkipPointsInCalculation() is set to TRUE.
        
        It is important that a renderer takes the scalings into account. When one of these parameters is unknown, no optimization must be done.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getFormattedRepresentation(self, xNumFmtSupplier: 'XNumberFormatsSupplier_3afb0fb7', nNumberFormatKey: int, nFormulaLength: int) -> str:
        """
        Returns a representation using the given number format for formatting all numbers contained in the formula.
        
        Wrap equation to fit in nFormulaLength characters
        """
    def getRepresentation(self) -> str:
        """
        Retrieve a string showing the regression curve's function with calculated parameters.
        """
    def recalculateRegression(self, aXValues: 'typing.Tuple[float, ...]', aYValues: 'typing.Tuple[float, ...]') -> None:
        """
        recalculates the parameters of the internal regression curve according to the x- and y-values given.
        """
    def setRegressionProperties(self, degree: int, forceIntercept: bool, interceptValue: float, period: int, movingType: int) -> None:
        """
        set calculation properties for curve calculation.
        """
    def setXYNames(self, aXName: str, aYName: str) -> None:
        """
        Set the names of X and Y variables of the equation to replace \"x\" and \"f(x)\" in representation.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal


class ReportPrintOption(object):
    """
    Const

    Specifies whether a page header or footer is printed on the same page as the report header or report footer.

    See Also:
        `API ReportPrintOption <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1report_1_1ReportPrintOption.html>`_
    """
    ALL_PAGES: Literal[0]
    """
    The page header/footer is printed on all pages.
    """
    NOT_WITH_REPORT_HEADER: Literal[1]
    """
    The page header/footer is not printed on the same page as the report header.
    """
    NOT_WITH_REPORT_FOOTER: Literal[2]
    """
    The page header/footer is not printed on the same page as the report footer.
    """
    NOT_WITH_REPORT_HEADER_FOOTER: Literal[3]
    """
    The page header/footer is not printed on the same page as the report header or footer.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..reflection.param_mode import ParamMode as ParamMode_d7260ca9
from .member_type import MemberType as MemberType_b1e00b97


class InvocationInfo(object):
    """
    Struct Class

    This struct is used to specify information about object members (methods or properties) accessed via XInvocation, such as names, types, or parameters.

    See Also:
        `API InvocationInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1InvocationInfo.html>`_
    """
    typeName: Literal['com.sun.star.script.InvocationInfo']

    def __init__(self, aParamTypes: typing.Optional[typing.Tuple[object, ...]] = ..., aParamModes: typing.Optional[typing.Tuple[ParamMode_d7260ca9, ...]] = ..., aName: typing.Optional[str] = ..., eMemberType: typing.Optional[MemberType_b1e00b97] = ..., PropertyAttribute: typing.Optional[int] = ..., aType: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            aParamTypes (typing.Tuple[object, ...], optional): aParamTypes value.
            aParamModes (typing.Tuple[ParamMode, ...], optional): aParamModes value.
            aName (str, optional): aName value.
            eMemberType (MemberType, optional): eMemberType value.
            PropertyAttribute (int, optional): PropertyAttribute value.
            aType (object, optional): aType value.
        """


    @property
    def aParamTypes(self) -> typing.Tuple[object, ...]:
        """
        Types method parameters, for properties this sequence is empty.
        """


    @property
    def aParamModes(self) -> typing.Tuple[ParamMode_d7260ca9, ...]:
        """
        Mode of method parameters (IN, OUT, INOUT), for properties this sequence is empty.
        """


    @property
    def aName(self) -> str:
        """
        Name of the method or property.
        """


    @property
    def eMemberType(self) -> MemberType_b1e00b97:
        """
        Kind of the member (method or property).
        """


    @property
    def PropertyAttribute(self) -> int:
        """
        Only for property members: This field may contain zero or more constants of the com.sun.star.beans.PropertyAttribute constants group.
        
        It is not guaranteed that all necessary constants are set to describe the property completely, but a flag will only be set, if the corresponding charac- teristic really exists. Example: If the READONLY flag is set, the property is readonly. If it isn't set, the property nevertheless can be readonly.
        
        For methods this field is irrelevant and is set to 0.
        """


    @property
    def aType(self) -> object:
        """
        Type of the member, for methods the return type.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_frame import XFrame as XFrame_7a570956
    from .x_model import XModel as XModel_7a6e095c

class XController(XComponent_98dc0ab5):
    """
    With this interface, components viewed in a Frame can serve events (by supplying dispatches).

    See Also:
        `API XController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XController']

    def attachFrame(self, Frame: 'XFrame_7a570956') -> None:
        """
        is called to attach the controller with its managing frame.
        """
    def attachModel(self, Model: 'XModel_7a6e095c') -> bool:
        """
        is called to attach the controller to a new model.
        """
    def getFrame(self) -> 'XFrame_7a570956':
        """
        provides access to owner frame of this controller
        """
    def getModel(self) -> 'XModel_7a6e095c':
        """
        provides access to currently attached model
        """
    def getViewData(self) -> object:
        """
        provides access to current view status
        """
    def restoreViewData(self, Data: object) -> None:
        """
        restores the view status using the data gotten from a previous call to XController.getViewData().
        """
    def suspend(self, Suspend: bool) -> bool:
        """
        is called to prepare the controller for closing the view
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .input_source import InputSource as InputSource_c88c0c54

class XEntityResolver(XInterface_8f010a43):
    """
    makes it possible to modify the behavior of resolving external preferences.
    
    Usually, the parser has a default behavior of resolving external references (See documentation of the parser implementation). Use this interface to modify or reimplement this behavior.

    See Also:
        `API XEntityResolver <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XEntityResolver.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XEntityResolver']

    def resolveEntity(self, sPublicId: str, sSystemId: str) -> 'InputSource_c88c0c54':
        """
        If aInputStream is a valid reference to an input stream, the parser uses this InputSource. Otherwise the parser seeks for the entity using its default behavior.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
import typing
from .x_text_content import XTextContent as XTextContent_b16e0ba5
if typing.TYPE_CHECKING:
    from ..table.x_cell import XCell as XCell_70d408e8
    from ..table.x_table_columns import XTableColumns as XTableColumns_c66d0c31
    from ..table.x_table_rows import XTableRows as XTableRows_a37e0afb
    from .x_text_table_cursor import XTextTableCursor as XTextTableCursor_e2f90d30

class XTextTable(XTextContent_b16e0ba5):
    """
    manages a text table.

    See Also:
        `API XTextTable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextTable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XTextTable']

    def createCursorByCellName(self, aCellName: str) -> 'XTextTableCursor_e2f90d30':
        """
        creates a text table cursor and returns the XTextTableCursor interface.
        
        Initially the cursor is positioned in the cell with the specified name.
        """
    def getCellByName(self, aCellName: str) -> 'XCell_70d408e8':
        """
        Example: The cell in the 4th column and third row has the name \"D3\".
        
        In cells that are split, the naming convention is more complex. In this case the name is a concatenation of the former cell name (i.e. \"D3\") and the number of the new column and row index inside of the original table cell separated by dots. This is done recursively.
        
        Example: If the cell \"D3\" is horizontally split, it now contains the cells \"D3.1.1\" and \"D3.1.2\"
        """
    def getCellNames(self) -> 'typing.Tuple[str, ...]':
        """
        """
    def getColumns(self) -> 'XTableColumns_c66d0c31':
        """
        """
    def getRows(self) -> 'XTableRows_a37e0afb':
        """
        """
    def initialize(self, nRows: int, nColumns: int) -> None:
        """
        determines the numbers of rows and columns of the text table.
        
        This method must be called after the object is created and before the object is insert or attached elsewhere.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from .visual_representation import VisualRepresentation as VisualRepresentation_2a2b0f4c

class XVisualObject(XInterface_8f010a43):
    """
    represents common visualization functionality for embedded objects.

    See Also:
        `API XVisualObject <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XVisualObject.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XVisualObject']

    def getMapUnit(self, nAspect: int) -> int:
        """
        retrieves map mode the object communicates in.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
    def getPreferredVisualRepresentation(self, nAspect: int) -> 'VisualRepresentation_2a2b0f4c':
        """
        retrieves visual representation of the object in preferable format.
        
        If the object persistence entry contains cached visual representation then it can be retrieved by using this method even in loaded state.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def getVisualAreaSize(self, nAspect: int) -> 'Size_576707ef':
        """
        gets the size of object's visual area.
        
        The size must be provided in logical units according to map mode the object communicates in.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def setVisualAreaSize(self, nAspect: int, aSize: 'Size_576707ef') -> None:
        """
        sets the size of object's visual area.
        
        The size must be provided in logical units according to map mode the object communicates in.
        
        If an object is inplace- or ui-active the method must not initiate repainting itself.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb.application
from typing_extensions import Literal
import typing
from ...ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from .x_copy_table_listener import XCopyTableListener as XCopyTableListener_ad581224

class XCopyTableWizard(XExecutableDialog_450f0fa1):
    """
    describes a wizard which can be used to copy table like data from one database to another.
    
    Copying table data between databases can be a complex task. Especially when it comes to matching field types in the source and in the target database, some heuristics, and sometimes support from the user doing the operation, are required.
    
    The copy table wizard described by this interfaces cares for those, and other, settings.
    
    **since**
    
        OOo 2.4

    See Also:
        `API XCopyTableWizard <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.application.XCopyTableWizard']

    def addCopyTableListener(self, Listener: 'XCopyTableListener_ad581224') -> None:
        """
        adds a listener which is to be notified of progress in the copy operation
        """
    def removeCopyTableListener(self, Listener: 'XCopyTableListener_ad581224') -> None:
        """
        removes a listener
        """
    @property
    def CreatePrimaryKey(self) -> object:
        """
        specifies that a new primary key is to be created in the target database
        
        At initialization time, you can specify the initial settings for the primary key in the UI.
        
        You cannot use this attribute to determine the primary key, possibly created by the wizard, after it finished. The reason is that during the wizard run, the user can define an arbitrarily complex primary key, e.g. including multiple columns, which cannot be represented in this simple attribute anymore.
        
        This attribute is ignored if Operation is CopyTableOperation.AppendData.
        
        Changing this attribute while the dialog is running is not supported, the result of such an attempt is undefined.
        
        When a primary key is to be created by the wizard, it will be an auto-increment column, if possible.
        """

    @property
    def DestinationTableName(self) -> str:
        """
        specifies the name of the table in the destination database.
        
        At initialization time, you can use this attribute to control the initial table name as suggested to the user.
        
        After the wizard has finished, you can use this attribute to determine what table was actually created resp. to which existing table the source table's data was appended.
        
        Changing this attribute while the dialog is running is not supported, the result of such an attempt is undefined.
        """

    @property
    def Operation(self) -> int:
        """
        specifies the basic operation for the wizard to execute.
        
        This must be one of the CopyTableOperation constants.
        
        At initialization time, you can use this attribute to control the initial operation in the wizard.
        
        After the wizard has finished, you can use this attribute to determine what operation was actually executed.
        
        Changing this attribute while the dialog is running is not supported, the result of such an attempt is undefined.
        """

    @property
    def UseHeaderLineAsColumnNames(self) -> bool:
        """
        specifies that the first row should be used to identify column names.
        
        This attribute is ignored when the source defines the column names which isn't the case when only a part of a table should be copied e.g. in the RTF format or in the HTML format.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..awt.size import Size as Size_576707ef
    from ..awt.x_bitmap import XBitmap as XBitmap_70cd0909
    from ..util.color import Color as Color_68e908c5

class NumberingLevel(ABC):
    """
    Service Class

    provides access to a numbering level as part of the Numbering Rules.
    
    **since**
    
        LibreOffice 3.6

    See Also:
        `API NumberingLevel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1NumberingLevel.html>`_
    """
    @property
    def Adjust(self) -> int:
        """
        adjusts the numbering (HoriOrientation_LEFT/RIGHT/CENTER)
        """
    @property
    def BulletChar(self) -> str:
        """
        contains the symbol in the given font.
        
        This is only valid if the numbering type is com.sun.star.style.NumberingType.CHAR_SPECIAL.
        """
    @property
    def BulletColor(self) -> 'Color_68e908c5':
        """
        contains the color for the symbol.
        
        This is only valid if the numbering type is com.sun.star.style.NumberingType.CHAR_SPECIAL.
        """
    @property
    def BulletFont(self) -> 'FontDescriptor_bc110c0a':
        """
        the font used to paint the bullet.
        """
    @property
    def BulletFontName(self) -> str:
        """
        the name of the font for the symbol.
        
        This is only valid if the numbering type is com.sun.star.style.NumberingType.CHAR_SPECIAL.
        """
    @property
    def BulletId(self) -> int:
        """
        the ID of the symbol in the given font.
        
        This is only valid if the numbering type is com.sun.star.style.NumberingType.CHAR_SPECIAL.
        """
    @property
    def BulletRelSize(self) -> int:
        """
        contains the size of the symbol relative to the high of the paragraph.
        
        This is only valid if the numbering type is com.sun.star.style.NumberingType.CHAR_SPECIAL.
        """
    @property
    def CharStyleName(self) -> str:
        """
        Name of the character style that is used for the numbering symbol.
        """
    @property
    def FirstLineIndent(self) -> int:
        """
        additional line indent for the first text line
        """
    @property
    def FirstLineOffset(self) -> int:
        """
        specifies the offset between the beginning of the first line and the beginning of the following lines of the paragraph.
        """
    @property
    def GraphicBitmap(self) -> 'XBitmap_70cd0909':
        """
        the graphic file that is used as the numbering symbol.
        
        This is only valid if the numbering type is com.sun.star.style.NumberingType.BITMAP.
        """
    @property
    def GraphicSize(self) -> 'Size_576707ef':
        """
        size of the graphic that is used as bullet.
        """
    @property
    def GraphicURL(self) -> str:
        """
        the URL of the graphic file that is used as the numbering symbol.
        
        This is only valid if the numbering type is com.sun.star.style.NumberingType.BITMAP.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the bitmap and set the GraphicBitmap property.
        """
    @property
    def HeadingStyleName(self) -> str:
        """
        contains the name of the paragraph style that is interpreted as the header of this level.
        
        It is only contained in the levels of chapter numbering rules.
        """
    @property
    def IndentAt(self) -> int:
        """
        indentation of the text lines
        """
    @property
    def LabelFollowedBy(self) -> int:
        """
        character following the list label
        """
    @property
    def LeftMargin(self) -> int:
        """
        specifies the left margin of the numbering
        """
    @property
    def ListtabStopPosition(self) -> int:
        """
        list tab position
        """
    @property
    def NumberingType(self) -> int:
        """
        specifies the type of numbering.
        """
    @property
    def ParagraphStyleName(self) -> str:
        """
        contains the name of the paragraph style that should use this numbering.
        
        This is ignored for chapter numbering rules, use HeadingStyleName.
        
        **since**
        
            LibreOffice 3.6
        """
    @property
    def ParentNumbering(self) -> int:
        """
        number of upper levels that are included in the current numbering symbol.
        """
    @property
    def PositionAndSpaceMode(self) -> int:
        """
        position and space mode
        """
    @property
    def Prefix(self) -> str:
        """
        the prefix of the numbering symbol.
        """
    @property
    def StartWith(self) -> int:
        """
        specifies the start value for the numbering.
        
        This property is only valid if the numbering type is not com.sun.star.style.NumberingType.BITMAP or com.sun.star.style.NumberingType.CHAR_SPECIAL.
        """
    @property
    def Suffix(self) -> str:
        """
        the suffix of the numbering symbol.
        """
    @property
    def SymbolTextDistance(self) -> int:
        """
        specifies the distance between the numbering symbol and the text of the paragraph.
        """
    @property
    def VertOrient(self) -> int:
        """
        contains the vertical orientation of a graphic.
        
        It is set using com.sun.star.text.VertOrientation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto.sax
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ...sax.x_attribute_list import XAttributeList as XAttributeList_eec70d7b


class ElementStackItem(object):
    """
    Struct Class

    A struct to keep a startElement/endElement SAX event.

    See Also:
        `API ElementStackItem <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1ElementStackItem.html>`_
    """
    typeName: Literal['com.sun.star.xml.crypto.sax.ElementStackItem']

    def __init__(self, isStartElementEvent: typing.Optional[bool] = ..., elementName: typing.Optional[str] = ..., xAttributes: typing.Optional[XAttributeList_eec70d7b] = ...) -> None:
        """
        Constructor

        Arguments:
            isStartElementEvent (bool, optional): isStartElementEvent value.
            elementName (str, optional): elementName value.
            xAttributes (XAttributeList, optional): xAttributes value.
        """


    @property
    def isStartElementEvent(self) -> bool:
        """
        whether it is a startElement event
        """


    @property
    def elementName(self) -> str:
        """
        the name of the element
        """


    @property
    def xAttributes(self) -> XAttributeList_eec70d7b:
        """
        attribute list for a startElement event
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.document
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from ..frame.x_controller2 import XController2 as XController2_bbcf0bc1


class DocumentEvent(EventObject_a3d70b03):
    """
    Struct Class

    describes an event happening in an OfficeDocument
    
    The com.sun.star.lang.EventObject.Source member of the base type refers to the document which broadcasts the event.
    
    This type is the successor of the EventObject type, which should not be used anymore.
    
    **since**
    
        OOo 3.1

    See Also:
        `API DocumentEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1document_1_1DocumentEvent.html>`_
    """
    typeName: Literal['com.sun.star.document.DocumentEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., EventName: typing.Optional[str] = ..., ViewController: typing.Optional[XController2_bbcf0bc1] = ..., Supplement: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            EventName (str, optional): EventName value.
            ViewController (XController2, optional): ViewController value.
            Supplement (object, optional): Supplement value.
        """


    @property
    def EventName(self) -> str:
        """
        specifies the name of the event.
        
        It's the responsibility of the component supporting the XDocumentEventBroadcaster interface to specify which events it supports.
        """


    @property
    def ViewController(self) -> XController2_bbcf0bc1:
        """
        denotes the view respectively controller which the event applies to.
        
        Might be NULL if the event is not related to a concrete view of the document.
        """


    @property
    def Supplement(self) -> object:
        """
        contains supplemental information about the event which is being notified
        
        The semantics of this additional information needs to be specified by the broadcaster of the event.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class ExternalReference(object):
    """
    Struct Class

    Data structure to store information about an external reference.
    
    An external reference can be either a single cell reference, a cell range reference, or a named range.
    
    **since**
    
        OOo 3.1

    See Also:
        `API ExternalReference <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1ExternalReference.html>`_
    """
    typeName: Literal['com.sun.star.sheet.ExternalReference']

    def __init__(self, Index: typing.Optional[int] = ..., Reference: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Index (int, optional): Index value.
            Reference (object, optional): Reference value.
        """


    @property
    def Index(self) -> int:
        """
        Index of an externally linked document.
        
        Each externally-linked document has a unique index value.
        
        You can get the index value of an external document from the corresponding com.sun.star.sheet.ExternalDocLink instance through its attribute com.sun.star.sheet.ExternalDocLink.TokenIndex.
        """


    @property
    def Reference(self) -> object:
        """
        Reference data.
        
        This can store either SingleReference for a single cell reference, ComplexReference for a cell range reference, or simply a string for a defined name.
        
        The SingleReference.Sheet member shall contain the index of the external sheet cache containing the values of the externally referenced cells.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
import typing
from ..beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet_7bd4114e
from .text_range import TextRange as TextRange_90540a5f
if typing.TYPE_CHECKING:
    from .x_footnote import XFootnote as XFootnote_901e0a73
    from .x_text_content import XTextContent as XTextContent_b16e0ba5
    from .x_text_field import XTextField as XTextField_9a630aae

class TextPortion(TextRange_90540a5f, XTolerantMultiPropertySet_7bd4114e):
    """
    Service Class

    A TextPortion is a piece of text within a paragraph that does not contain changes of its attributes inside.
    
    It is created by an enumeration implemented in a paragraph service. It may be used to export the content of the paragraph to an external document format.
    
    **since**
    
        OOo 2.0

    See Also:
        `API TextPortion <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html>`_
    """
    @property
    def Bookmark(self) -> 'XTextContent_b16e0ba5':
        """
        contains the bookmark of a text portion of type Bookmark.
        """
    @property
    def ControlCharacter(self) -> int:
        """
        contains the control character of a text portion of type ControlCharacter.
        """
    @property
    def DocumentIndexMark(self) -> 'XTextContent_b16e0ba5':
        """
        contains the document index mark of a text portion of type DocumentIndexMark.
        """
    @property
    def Footnote(self) -> 'XFootnote_901e0a73':
        """
        contains the footnote of a text portion of type Footnote.
        """
    @property
    def InContentMetadata(self) -> 'XTextContent_b16e0ba5':
        """
        contains the text range of a text portion of type InContentMetadata.
        
        **since**
        
            OOo 3.2
        """
    @property
    def IsCollapsed(self) -> bool:
        """
        contains whether the portion is a point only.
        """
    @property
    def IsStart(self) -> bool:
        """
        contains whether the portion is the start of the portion.
        
        This is used for portions which are represented by 2 TextPortion objects (e.g., DocmentIndexMark).
        """
    @property
    def ReferenceMark(self) -> 'XTextContent_b16e0ba5':
        """
        contains the bookmark of a text portion of type ReferenceMark.
        """
    @property
    def TextField(self) -> 'XTextField_9a630aae':
        """
        contains the text field of a text portion of type TextField.
        """
    @property
    def TextPortionType(self) -> str:
        """
        contains the type of the text portion.
        
        Valid content type names are:
        
        For Reference marks, document index marks, etc., 2 text portions will be generated, one for the start position and one for the end position.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.control
from ..submission.x_submission import XSubmission as XSubmission_3cfd0fba

class SubmitButton(XSubmission_3cfd0fba):
    """
    Service Class

    specifies a button control which can execute external submissions
    
    The model of the control has to support the com.sun.star.form.component.SubmitButton service.
    
    The control is clickable. When clicked (by mouse or keyboard, or programmatically), the following happens:

    See Also:
        `API SubmitButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1SubmitButton.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from ..style.numbering_rule import NumberingRule as NumberingRule_cb530c78

class ChapterNumberingRule(NumberingRule_cb530c78):
    """
    Service Class

    describes the rules for chapter numbering in a text document.
    
    Some of the properties that are available in the interface are ignored here.
    
    The type of numbering can only be: NUM_CHARS_UPPER_LETTER, NUM_CHARS_LOWER_LETTER, NUM_ROMAN_UPPER, NUM_ROMAN_LOWER, NUM_ARABIC, or NUM_NUMBER_NONE
    
    In the com.sun.star.style.NumberingAlignment only the field com.sun.star.style.NumberingAlignment.Alignment is applied.
    
    Depending on the numbering types, the parameters for bullets or bit maps may be ignored. The character style name for the numbering symbol is also ignored.

    See Also:
        `API ChapterNumberingRule <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1ChapterNumberingRule.html>`_
    """
    @property
    def HeadingStyleName(self) -> str:
        """
        contains the name of the paragraph style that marks this heading level.
        
        It is necessary that each style name appears only once in the sequence of numbering rules.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal
"""
Const

Specifies how to group data.

See Also:
    `API GroupOn <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1report_1_1GroupOn.html>`_
"""
DEFAULT: Literal[0]
"""
The same value in the column value or expression.
"""
PREFIX_CHARACTERS: Literal[1]
"""
The same first nth of characters in the column value or expression.
"""
YEAR: Literal[2]
"""
Dates in the same calendar year.
"""
QUARTAL: Literal[3]
"""
Dates in the same calendar quarter.
"""
MONTH: Literal[4]
"""
Dates in the same month.
"""
WEEK: Literal[5]
"""
Dates in the same week.
"""
DAY: Literal[6]
"""
Dates on the same date.
"""
HOUR: Literal[7]
"""
Times in the same hour.
"""
MINUTE: Literal[8]
"""
Times in the same minute.
"""
INTERVAL: Literal[9]
"""
Values within an interval you specify.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_storable import XStorable as XStorable_998f0aa7
    from ..ucb.x_content import XContent as XContent_79db0975

class XDocumentTemplates(XInterface_8f010a43):
    """
    provides a high level API to organize document templates
    
    Template information is saved as links to the original content and organized in groups. This data should be persistent and can be updated by calling special method XDocumentTemplates.update(). A real implementation of this interface can do that on top of a ucb content provider. Method XDocumentTemplates.getContent() force that.

    See Also:
        `API XDocumentTemplates <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDocumentTemplates.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XDocumentTemplates']

    def addGroup(self, GroupName: str) -> bool:
        """
        creates a new group
        """
    def addTemplate(self, GroupName: str, TemplateName: str, SourceURL: str) -> bool:
        """
        creates the template with the given name in the given group using the given URL
        """
    def getContent(self) -> 'XContent_79db0975':
        """
        provides access to the root of internal used hierarchy
        
        This content can be used for accessing the groups directly.
        """
    def removeGroup(self, GroupName: str) -> bool:
        """
        remove an existing group
        """
    def removeTemplate(self, GroupName: str, TemplateName: str) -> bool:
        """
        remove a template from specified group
        """
    def renameGroup(self, OldGroupName: str, NewGroupName: str) -> bool:
        """
        rename an existing group
        """
    def renameTemplate(self, GroupName: str, OldTemplateName: str, NewTemplateName: str) -> bool:
        """
        rename a template inside specified group
        """
    def storeTemplate(self, GroupName: str, TemplateName: str, Storable: 'XStorable_998f0aa7') -> bool:
        """
        creates the template with the given name in the given group using the data from the storable
        """
    def update(self) -> None:
        """
        force an update for internal structures
        
        Because the templates are well known by links and not as direct content they can be outdated. An update force actualization of that to find wrong links.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.crypto
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...security.x_certificate import XCertificate as XCertificate_e55b0d3b

class XSecurityEnvironment(XInterface_8f010a43):
    """
    Interface of Security Environment.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API XSecurityEnvironment <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XSecurityEnvironment.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.crypto.XSecurityEnvironment']

    def buildCertificatePath(self, beginCert: 'XCertificate_e55b0d3b') -> 'typing.Tuple[XCertificate_e55b0d3b, ...]':
        """
        Build certificate path from a certain certificate.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
    def createCertificateFromAscii(self, asciiCertificate: str) -> 'XCertificate_e55b0d3b':
        """
        Create certificate interface from a Base64 encoded certificate.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
    def createCertificateFromRaw(self, rawCertificate: 'typing.Tuple[int, ...]') -> 'XCertificate_e55b0d3b':
        """
        Create certificate interface from raw DER encoded certificate.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
    def getAllCertificates(self) -> 'typing.Tuple[XCertificate_e55b0d3b, ...]':
        """
        List all certificates, private (as returned by getPersonalCertificates) as well as those of other people/orgas.
        
        **since**
        
            LibreOffice 6.0

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
    def getCertificate(self, issuerName: str, serialNumber: 'typing.Tuple[int, ...]') -> 'XCertificate_e55b0d3b':
        """
        Get certificate from the environment by issuer name and serial number.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
    def getCertificateCharacters(self, xCertificate: 'XCertificate_e55b0d3b') -> int:
        """
        Get a certificate characters.
        
        The method provides a way to get certificate characters like:
        
        The certificate characters is defined as bit-wise long, please refer to CertificateCharacters definition.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
    def getPersonalCertificates(self) -> 'typing.Tuple[XCertificate_e55b0d3b, ...]':
        """
        Get personal certificates from the environment.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
    def getSecurityEnvironmentInformation(self) -> str:
        """
        Get the Environment detail information.
        """
    def verifyCertificate(self, xEECertificate: 'XCertificate_e55b0d3b', intermediateCertificates: 'typing.Tuple[XCertificate_e55b0d3b, ...]') -> int:
        """
        Verify a certificate.
        
        The method provides a way to verify a certificate.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from .x_content_identifier_factory import XContentIdentifierFactory as XContentIdentifierFactory_56b91050
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0
from .x_parameterized_content_provider import XParameterizedContentProvider as XParameterizedContentProvider_9dc6120d

class RemoteProxyContentProvider(XContentIdentifierFactory_56b91050, XContentProvider_d4150cc0, XParameterizedContentProvider_9dc6120d):
    """
    Service Class

    A ContentProvider that wraps remote content providers that (potentially) have been distributed to a UCB.
    
    Before trying to pass a request to a \"real\", underlying content provider (which will most likely be a remote content provider distributed to this UCB), this proxy first activates any remote content providers that have been distributed here, but are still inactive (see RemoteContentProviderAcceptor and XRemoteContentProviderActivator for more information).
    
    The way this works might change, therefore this interface is marked as deprecated.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API RemoteProxyContentProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteProxyContentProvider.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from .x_string_substitution import XStringSubstitution as XStringSubstitution_f660eb2

class PathSubstitution(XStringSubstitution_f660eb2):
    """
    Service Class

    A service to support the substitution and resubstitution of path variables.
    
    A path variable must be specified with the following syntax: \"$(\"<variable-name>\")\". Path variables are not case sensitive and are always provided as a UCB-compliant URLs (for example: \"file:///c:/temp\" or \"file:///usr/install\"). This is mandatory to support an optional remote file system.
    There is a set of variables that have pre-defined values:
    
    Attention: Most predefined variables describe an absolute path. The only exceptions are: $(username), $(langid) and $(vlang). Therefore the service implementation should only substitute variables which are located at the start of a provided path string or are part of a multi-path. This special service is not designed to be a text substitution but shall provide (a) valid substituted path(s).
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API PathSubstitution <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1PathSubstitution.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XStorageRawAccess(ABC):
    """
    This interface represents main storage functionality.

    See Also:
        `API XStorageRawAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XStorageRawAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XStorageRawAccess']

    def getPlainRawStreamElement(self, sStreamName: str) -> 'XInputStream_98d40ab4':
        """
        allows to get a plain raw stream representing a package stream.
        
        This method returns a stream from the package as it is stored there, without any decompression/description and etc. This method can be helpful to check file consistency, for example by signing.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def getRawEncrStreamElement(self, sStreamName: str) -> 'XInputStream_98d40ab4':
        """
        allows to get a raw stream representing encrypted stream with header.
        
        This method allows to transport encrypted streams without decryption. Mainly this method is introduced to allow to copy one encrypted storage stream to another without decryption. It is not recommended to use this method outside of storage implementation since different storages implementation could have different encryption format. If the method is used outside of storage implementation the user code is responsible to get sure that the raw format of source and target storages is the same.
        
        The difference of this method from the previous one is that it handles only encrypted streams. The contents of returned by these methods streams can differ for the same entry, since this method can add additional data into the stream to allow successful insertion.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
    def insertRawEncrStreamElement(self, sStreamName: str, xInStream: 'XInputStream_98d40ab4') -> None:
        """
        allows to insert a raw stream representing encrypted stream with header.
        
        This method allows to insert a stream retrieved by XStorageRawAccess.getRawEncrStreamElement() into a storage.
        
        This method allows to transport encrypted streams without decryption. Mainly this method is introduced to allow to copy one encrypted storage stream to another without decryption. It is not recommended to use this method outside of storage implementation since different storages implementation could have different encryption format.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoRawFormatException: ``NoRawFormatException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.style
from typing_extensions import Literal
"""
Const

These constants are used to specify which numbering style is used.

**since**

    LibreOffice 7.0

See Also:
    `API NumberingType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style_1_1NumberingType.html>`_
"""
CHARS_UPPER_LETTER: Literal[0]
"""
Numbering is put in upper case letters as \"A, B, C, D, ...\".
"""
CHARS_LOWER_LETTER: Literal[1]
"""
Numbering is in lower case letters as \"a, b, c, e,...\".
"""
ROMAN_UPPER: Literal[2]
"""
Numbering is in Roman numbers with upper case letters as \"I, II, III, IV, ...\".
"""
ROMAN_LOWER: Literal[3]
"""
Numbering is in Roman numbers with lower case letters as \"i, ii, iii, iv, ...\".
"""
ARABIC: Literal[4]
"""
Numbering is in Arabic numbers as \"1, 2, 3, 4, ...\".
"""
NUMBER_NONE: Literal[5]
"""
Numbering is invisible.
"""
CHAR_SPECIAL: Literal[6]
"""
Use a character from a specified font.
"""
PAGE_DESCRIPTOR: Literal[7]
"""
Numbering is specified in the page style.
"""
BITMAP: Literal[8]
"""
Numbering is displayed as a bitmap graphic.
"""
CHARS_UPPER_LETTER_N: Literal[9]
"""
Numbering is put in upper case letters as \"A, B, ..., Y, Z, AA, BB, CC, ...

AAA, ...\".
"""
CHARS_LOWER_LETTER_N: Literal[10]
"""
Numbering is put in lower case letters as \"a, b, ..., y, z, aa, bb, cc, ...

aaa, ...\".
"""
TRANSLITERATION: Literal[11]
"""
A transliteration module will be used to produce numbers in Chinese, Japanese, etc.
"""
NATIVE_NUMBERING: Literal[12]
"""
The NativeNumberSupplier service will be called to produce numbers in native languages.
"""
FULLWIDTH_ARABIC: Literal[13]
"""
Numbering for fullwidth Arabic number.
"""
CIRCLE_NUMBER: Literal[14]
"""
Bullet for Circle Number.
"""
NUMBER_LOWER_ZH: Literal[15]
"""
Numbering for Chinese lower case number as \"&#19968;,&#20108;,&#19977;...\".
"""
NUMBER_UPPER_ZH: Literal[16]
"""
Numbering for Chinese upper case number.
"""
NUMBER_UPPER_ZH_TW: Literal[17]
"""
Numbering for Traditional Chinese upper case number.
"""
TIAN_GAN_ZH: Literal[18]
"""
Bullet for Chinese Tian Gan as \"&#30002;,&#20057;,&#19993;...\".
"""
DI_ZI_ZH: Literal[19]
"""
Bullet for Chinese Di Zi as \"&#23376;,&#19985;,&#23493;...\".
"""
NUMBER_TRADITIONAL_JA: Literal[20]
"""
Numbering for Japanese traditional number.
"""
AIU_FULLWIDTH_JA: Literal[21]
"""
Bullet for Japanese AIU fullwidth.
"""
AIU_HALFWIDTH_JA: Literal[22]
"""
Bullet for Japanese AIU halfwidth.
"""
IROHA_FULLWIDTH_JA: Literal[23]
"""
Bullet for Japanese IROHA fullwidth.
"""
IROHA_HALFWIDTH_JA: Literal[24]
"""
Bullet for Japanese IROHA halfwidth.
"""
NUMBER_UPPER_KO: Literal[25]
"""
Numbering for Korean upper case number as \"&#22777;,&#36019;,&#21443;...\".
"""
NUMBER_HANGUL_KO: Literal[26]
"""
Numbering for Korean Hangul number as \"&#51068;,&#51060;,&#49340;...\".
"""
HANGUL_JAMO_KO: Literal[27]
"""
Bullet for Korean Hangul Jamo as \"&#12593;,&#12596;,&#12599;...\".
"""
HANGUL_SYLLABLE_KO: Literal[28]
"""
Bullet for Korean Hangul Syllable as \"&#44032;,&#45208;,&#45796;...\".
"""
HANGUL_CIRCLED_JAMO_KO: Literal[29]
"""
Bullet for Korean Hangul Circled Jamo as \"&#12896;,&#12897;,&#12898;...\".
"""
HANGUL_CIRCLED_SYLLABLE_KO: Literal[30]
"""
Bullet for Korean Hangul Circled Syllable as \"&#12910;,&#12911;,&#12912;...\".
"""
CHARS_ARABIC: Literal[31]
"""
Numbering in Arabic alphabet letters as \"&#1571;,&#1576;,&#1578;...\".

**since**

    OOo 1.1.2
"""
CHARS_THAI: Literal[32]
"""
Numbering in Thai alphabet letters.

**since**

    OOo 1.1.2
"""
CHARS_HEBREW: Literal[33]
"""
Numbering in Hebrew alphabet letters.

**since**

    OOo 2.0
"""
CHARS_NEPALI: Literal[34]
"""
Numbering in Nepali alphabet letters.

**since**

    OOo 2.0.1
"""
CHARS_KHMER: Literal[35]
"""
Numbering in Khmer alphabet letters.

**since**

    OOo 2.0.1
"""
CHARS_LAO: Literal[36]
"""
Numbering in Lao alphabet letters.

**since**

    OOo 2.0.1
"""
CHARS_TIBETAN: Literal[37]
"""
Numbering in Tibetan/Dzongkha alphabet letters.

**since**

    OOo 2.0.3
"""
CHARS_CYRILLIC_UPPER_LETTER_BG: Literal[38]
"""
Numbering in Cyrillic alphabet upper case letters as \"&#1040;, &#1041;,  &#1042;, &#1043;, ..., &#1070;, &#1071;, &#1040;&#1074;, &#1040;&#1072;, &#1040;&#1074;, ... &#1040;&#1072;&#1072;, &#1040;&#1072;&#1073;\".

**since**

    OOo 2.0.4
"""
CHARS_CYRILLIC_LOWER_LETTER_BG: Literal[39]
"""
Numbering in Cyrillic alphabet lower case letters as \"&#1072;, &#1073;, &#1074;, &#1075;, ..., &#1102;, &#1103;, &#1072; &#1072;,  &#1072;&#1073;, &#1072;&#1074;, ...  &#1072; &#1072; &#1072;,  &#1072; &#1072;&#1073;\".

**since**

    OOo 2.0.4
"""
CHARS_CYRILLIC_UPPER_LETTER_N_BG: Literal[40]
"""
Numbering in Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1041;&#1073;, &#1042;&#1074;, ... &#1040;&#1072;&#1072;, ...\".

**since**

    OOo 2.0.4
"""
CHARS_CYRILLIC_LOWER_LETTER_N_BG: Literal[41]
"""
Numbering in Cyrillic alphabet upper case letters as \"&#1072;, &#1073;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1073;&#1073;, &#1074;&#1074;, ... &#1072;&#1072;&#1072;, ...\".

**since**

    OOo 2.0.4
"""
CHARS_CYRILLIC_UPPER_LETTER_RU: Literal[42]
"""
Numbering in Russian Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, &#1042;, &#1043;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1040;&#1073;, &#1040;&#1074;, ... &#1040;&#1072;&#1072;, &#1040;&#1072;&#1073;\".

**since**

    OOo 2.0.4
"""
CHARS_CYRILLIC_LOWER_LETTER_RU: Literal[43]
"""
Numbering in Russian Cyrillic alphabet lower case letters as \"&#1072;, &#1073;, &#1074;, &#1075;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1072;&#1073;, &#1072;&#1074;, ... &#1072;&#1072;&#1072;, &#1072;&#1072;&#1073;\".

**since**

    OOo 2.0.4
"""
CHARS_CYRILLIC_UPPER_LETTER_N_RU: Literal[44]
"""
Numbering in Russian Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1041;&#1073;, &#1042;&#1074;, ... &#1040;&#1072;&#1072;, ...\".

**since**

    OOo 2.0.4
"""
CHARS_CYRILLIC_LOWER_LETTER_N_RU: Literal[45]
"""
Numbering in Russian Cyrillic alphabet upper case letters as \"&#1072;, &#1073;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1073;&#1073;, &#1074;&#1074;, ... &#1072;&#1072;&#1072;, ...\".

**since**

    OOo 2.0.4
"""
CHARS_PERSIAN: Literal[46]
"""
Numbering in Persian alphabet letters (aa, be, pe, te, ...)

**since**

    OOo 2.4
"""
CHARS_MYANMAR: Literal[47]
"""
Numbering in Myanmar alphabet letters.

**since**

    OOo 3.1
"""
CHARS_CYRILLIC_UPPER_LETTER_SR: Literal[48]
"""
Numbering in Serbian Cyrillic alphabet upper case letters.

**since**

    OOo 3.1
"""
CHARS_CYRILLIC_LOWER_LETTER_SR: Literal[49]
"""
Numbering in Russian Serbian alphabet lower case letters.

**since**

    OOo 3.1
"""
CHARS_CYRILLIC_UPPER_LETTER_N_SR: Literal[50]
"""
Numbering in Serbian Cyrillic alphabet upper case letters.

**since**

    OOo 3.1
"""
CHARS_CYRILLIC_LOWER_LETTER_N_SR: Literal[51]
"""
Numbering in Serbian Cyrillic alphabet upper case letters.

**since**

    OOo 3.1
"""
CHARS_GREEK_UPPER_LETTER: Literal[52]
"""
Numbering in Greek alphabet upper case letters.

**since**

    LibreOffice 3.3
"""
CHARS_GREEK_LOWER_LETTER: Literal[53]
"""
Numbering in Greek alphabet lower case letters.

**since**

    LibreOffice 3.3
"""
CHARS_ARABIC_ABJAD: Literal[54]
"""
Numbering in Arabic alphabet using abjad sequence.

**since**

    LibreOffice 3.5
"""
CHARS_PERSIAN_WORD: Literal[55]
"""
Numbering in Persian words.

**since**

    LibreOffice 3.5
"""
NUMBER_HEBREW: Literal[56]
"""
Numbering in Hebrew numerals.

**since**

    LibreOffice 5.4
"""
NUMBER_ARABIC_INDIC: Literal[57]
"""
Numbering in Arabic-Indic numerals.

**since**

    LibreOffice 6.1
"""
NUMBER_EAST_ARABIC_INDIC: Literal[58]
"""
Numbering in East Arabic-Indic numerals.

**since**

    LibreOffice 6.1
"""
NUMBER_INDIC_DEVANAGARI: Literal[59]
"""
Numbering in Indic Devanagari numerals.

**since**

    LibreOffice 6.1
"""
TEXT_NUMBER: Literal[60]
"""
Numbering in ordinal numbers of the language of the text node for example, 1st, 2nd, 3rd...

in English

**since**

    LibreOffice 6.1
"""
TEXT_CARDINAL: Literal[61]
"""
Numbering in cardinal numbers of the language of the text node for example, One, Two, Three...

in English

**since**

    LibreOffice 6.1
"""
TEXT_ORDINAL: Literal[62]
"""
Numbering in ordinal numbers of the language of the text node for example, First, Second, Third...

in English

**since**

    LibreOffice 6.1
"""
SYMBOL_CHICAGO: Literal[63]
"""
Footnoting symbols according the University of Chicago style: *, &#2020;, &#2021;, &#00a7;, **, &#2020;&#2020; etc.

**since**

    LibreOffice 6.4
"""
ARABIC_ZERO: Literal[64]
"""
Numbering is in Arabic numbers, padded with zero to have a length of at least two, as \"01,
02, ..., 10, 11, ...\".

**since**

    LibreOffice 7.0
"""
ARABIC_ZERO3: Literal[65]
"""
Numbering is in Arabic numbers, padded with zero to have a length of at least three, as \"001, 002, ..., 100, 101, ...\".

**since**

    LibreOffice 7.0
"""
ARABIC_ZERO4: Literal[66]
"""
Numbering is in Arabic numbers, padded with zero to have a length of at least four, as \"0001, 0002, ..., 1000, 1001, ...\".

**since**

    LibreOffice 7.0
"""
ARABIC_ZERO5: Literal[67]
"""
Numbering is in Arabic numbers, padded with zero to have a length of at least five, as \"00001, 00002, ..., 10000, 10001, ...\".

**since**

    LibreOffice 7.0
"""
SZEKELY_ROVAS: Literal[68]
"""
Numbering is in Szekely rovas (Old Hungarian) numerals.

**since**

    LibreOffice 7.1
"""
NUMBER_DIGITAL_KO: Literal[69]
"""
Numbering is in Korean Digital number as \"ì¼,ì´,ì¼,...,ì¼ì,ì¼ìì, ...\".

**since**

    LibreOffice 7.3
"""
NUMBER_DIGITAL2_KO: Literal[70]
"""
Numbering is in Korean Digital Number, reserved \"koreanDigital2\", as \"ä¸,äº,ä¸,...,ä¸ï¦²,ä¸ï¦²ï¦², ...\".

**since**

    LibreOffice 7.3
"""
NUMBER_LEGAL_KO: Literal[71]
"""
Numbering is in Korean Legal Number, reserved \"koreanLegal\", as \"íë,ë,ì
,...\".

**since**

    LibreOffice 7.3
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.lang
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..uno.runtime_exception import RuntimeException as RuntimeException_d7390ced
from ..uno.x_interface import XInterface as XInterface_8f010a43

class DisposedException(RuntimeException_d7390ced):
    """
    Exception Class

    This exception occurs if the object behind this interface has been disposed before and can't uphold its method specification anymore.
    
    The implementation normally should implement the com.sun.star.lang.XComponent interface to indicate this possibility.

    See Also:
        `API DisposedException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1lang_1_1DisposedException.html>`_
    """

    typeName: Literal['com.sun.star.lang.DisposedException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['DisposedException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .x_data_series import XDataSeries as XDataSeries_b8150b89
from .data.x_labeled_data_sequence import XLabeledDataSequence as XLabeledDataSequence_7e1a10c8


class InterpretedData(object):
    """
    Struct Class

    offers tooling to interpret different data sources in a structural and chart-type-dependent way.

    See Also:
        `API InterpretedData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1InterpretedData.html>`_
    """
    typeName: Literal['com.sun.star.chart2.InterpretedData']

    def __init__(self, Series: typing.Optional[typing.Tuple[typing.Tuple[XDataSeries_b8150b89, ...], ...]] = ..., Categories: typing.Optional[XLabeledDataSequence_7e1a10c8] = ...) -> None:
        """
        Constructor

        Arguments:
            Series (typing.Tuple[typing.Tuple[XDataSeries, ...], ...], optional): Series value.
            Categories (XLabeledDataSequence, optional): Categories value.
        """


    @property
    def Series(self) -> typing.Tuple[typing.Tuple[XDataSeries_b8150b89, ...], ...]:
        ...


    @property
    def Categories(self) -> XLabeledDataSequence_7e1a10c8:
        ...





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_database_environment import XDatabaseEnvironment as XDatabaseEnvironment_8280e43
if typing.TYPE_CHECKING:
    from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class DatabaseEnvironment(XPropertySet_bc180bfa, XDatabaseEnvironment_8280e43):
    """
    Service Class

    It enables the service user to establish connections to databases or to use database access beans to gain access to database components. This service takes control over all other database services.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DatabaseEnvironment <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseEnvironment.html>`_
    """
    @property
    def NumberFormatsSupplier(self) -> 'XNumberFormatsSupplier_3afb0fb7':
        """
        provides an object for formatting numbers.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..container.x_string_key_map import XStringKeyMap as XStringKeyMap_ffc60de1


class TextMarkupDescriptor(object):
    """
    Struct Class

    A descriptor for a single text markup.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API TextMarkupDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1TextMarkupDescriptor.html>`_
    """
    typeName: Literal['com.sun.star.text.TextMarkupDescriptor']

    def __init__(self, nType: typing.Optional[int] = ..., aIdentifier: typing.Optional[str] = ..., nOffset: typing.Optional[int] = ..., nLength: typing.Optional[int] = ..., xMarkupInfoContainer: typing.Optional[XStringKeyMap_ffc60de1] = ...) -> None:
        """
        Constructor

        Arguments:
            nType (int, optional): nType value.
            aIdentifier (str, optional): aIdentifier value.
            nOffset (int, optional): nOffset value.
            nLength (int, optional): nLength value.
            xMarkupInfoContainer (XStringKeyMap, optional): xMarkupInfoContainer value.
        """


    @property
    def nType(self) -> int:
        """
        Type of text markup see TextMarkupType.
        """


    @property
    def aIdentifier(self) -> str:
        """
        A string used to identify the caller.
        """


    @property
    def nOffset(self) -> int:
        """
        Start of the markup range.
        """


    @property
    def nLength(self) -> int:
        """
        Length of the markup range.
        """


    @property
    def xMarkupInfoContainer(self) -> XStringKeyMap_ffc60de1:
        """
        contains additional information about the markup
        
        Supported properties:
        
        |
        
        **since**
        
            6.3: BOLDWAVE, BOLD | See: com::sun::star::awt::FontUnderline
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
from .x_simple_file_access2 import XSimpleFileAccess2 as XSimpleFileAccess2_ebe60d08

class XSimpleFileAccess3(XSimpleFileAccess2_ebe60d08):
    """
    This is an extension to the interface XSimpleFileAccess2.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSimpleFileAccess3 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XSimpleFileAccess3.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XSimpleFileAccess3']

    def isHidden(self, FileURL: str) -> bool:
        """
        Checks if a file is \"hidden\".

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def setHidden(self, FileURL: str, bHidden: bool) -> None:
        """
        Sets the \"hidden\" of a file according to the boolean parameter, if the actual process has the right to do so and the used operation system supports this operation.

        Raises:
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
"""
Const

These codes are used to indicate errors.

.. deprecated::

    Class is deprecated.

See Also:
    `API Error <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1Error.html>`_
"""
NONE: Literal[0]
LOGIN_FAILURE_RECEIVE: Literal[122880]
LOGIN_FAILURE_NEWSSEND: Literal[122881]
LOGIN_FAILURE_MAILSEND: Literal[122882]
CONNECT_FAILURE: Literal[122883]
UCB_OFFLINE: Literal[122884]
UCB_SERVER_ERROR: Literal[122885]
STORAGE_READONLY: Literal[122886]
STORAGE_KILLED: Literal[122887]
WRONG_FILE_FORMAT: Literal[122888]
UNSUPPORTED_URL: Literal[122889]
CNTOUT_NO_FROM: Literal[122890]
TOO_MANY_GROUPS: Literal[122891]
DELETE_ABORTED: Literal[122892]
QUERY_DELETE: Literal[122893]
NOTAVAILABLE: Literal[122894]
VIM_LIBRARY_ERROR: Literal[122895]
FOLDER_INVALID: Literal[122896]
FTP_RESOLVERERROR: Literal[122897]
FTP_NETWORKERROR: Literal[122898]
FTP_NOTNECESSARYCMD: Literal[122899]
FTP_SERVICEUNAVAILABLE: Literal[122900]
FTP_DCONFAILURE: Literal[122901]
FTP_TRANSFERABORTED: Literal[122902]
NO_VIM_LIBRARY: Literal[122903]
VIM_LIBRARY_CORRUPTED: Literal[122904]
CCMAIL_EXPORT_ERROR: Literal[122905]
NO_CCMAIL_EXPORT_FILE: Literal[122906]
ILLEGAL_CCMAIL_EXPORT_FILE: Literal[122907]
MESSAGE_NOT_FOUND: Literal[122908]
BAD_CCMAIL_EXPORT_PASSWORD: Literal[122909]
CCMAIL_EXPORT_TOO_LONG: Literal[122910]
FOLDER_EXISTS: Literal[122911]
FOLDER_NOT_EXISTS: Literal[122912]
NO_VIM_BBOARDLIST: Literal[122913]
ILLEGAL_MESSAGE_ID: Literal[122914]
SERVER_PORT_SYNTAX: Literal[122915]
SERVERNAME_SYNTAX: Literal[122916]
USERNAME_SYNTAX: Literal[122917]
IS_RESCHEDULED: Literal[122918]
VIM_NO_FAKE_MESSAGE_ID: Literal[122919]
FSYS_ROOT_DELETE: Literal[122920]
FILE_EXISTS: Literal[122921]
FILE_NOT_EXISTS: Literal[122922]
FSYS_MISPLACED_CHAR: Literal[122923]
FSYS_INVALID_CHAR: Literal[122924]
FSYS_INVALID_DEVICE: Literal[122925]
FSYS_ACCESS_DENIED: Literal[122926]
FSYS_LOCK_VIOLATION: Literal[122927]
FSYS_VOLUME_FULL: Literal[122928]
FSYS_NOT_SUPPORTED: Literal[122929]
FSYS_UNKNOWN: Literal[122930]
FSYS_NOT_A_FILE: Literal[122931]
FSYS_NOT_A_DIRECTORY: Literal[122932]
FSYS_IS_WILDCARD: Literal[122933]
RENAMED_WRONG_FILE_FORMAT: Literal[122934]
FSYS_UPDATE_NEEDED: Literal[122935]
FSYS_CANT_RESOLVE_CONFLICT: Literal[122936]
FSYS_CANT_ITERATE: Literal[122937]
ONE_NOT_SEARCHABLE: Literal[122938]
MULTIPLE_NOT_SEARCHABLE: Literal[122939]
FSYS_CACHE_INCONSISTENT: Literal[122940]
FSYS_READONLY: Literal[122941]
FSYS_LOCK: Literal[122942]
FSYS_UNLOCK: Literal[122943]
FSYS_DELETE: Literal[122944]
FSYS_IS_MARKED: Literal[122945]
FTP_GENERAL_FAILURE: Literal[122946]
DO_LOG: Literal[122947]
HTTP_COOKIE_REQUEST: Literal[122948]
FSYS_LOST_ROOT: Literal[122949]
FTP_PROXY: Literal[122950]
SOURCE_SAME_AS_TARGET: Literal[122951]
CONFIRM_EMPTY_TRASH: Literal[122952]
FSYS_NO_TARGET: Literal[122953]
FSYS_RECURSIVE: Literal[122954]
FSYS_INSERT_MEDIUM: Literal[122955]
NO_DOCINFO: Literal[122956]
CCMAIL_EXPORT_NOT_TERMINATING: Literal[122957]
EXTERNAL_COMMAND_FAILED: Literal[122958]
RENAME_FAILED: Literal[122959]
NOT_HANDLED: Literal[122960]
COULD_NOT_INIT_COMPONENT: Literal[122961]
TRANSFER_URL_NOT_SUPPORTED: Literal[122962]
EMPTY_SERVERNAME: Literal[122963]
EMPTY_USERNAME: Literal[122964]
BAD_INET: Literal[122965]
IMAP_SERVER_MSG: Literal[122966]
IMAP_CONNECTION_CLOSED: Literal[122967]
IMAP_NOT_IMAP4: Literal[122968]
IMAP_BAD_SERVER: Literal[122969]
REORGANIZE_FILE_LOCKED: Literal[122970]
IMAP_BAD_TITLE: Literal[122971]
SERVER_CONNECT_FAILURE: Literal[122972]
PASSWORD_SYNTAX: Literal[122973]
QUERY_DELETE_CACHE: Literal[122974]
REORGANIZE_NO_DISKSPACE: Literal[122975]
LOGIN_FAILURE_ACCOUNT: Literal[122976]
ACCOUNT_SYNTAX: Literal[122977]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API TransliterationModulesNew <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020>`_
"""

CharToNumHangul_ko: 'uno.Enum'
"""
Transliterate a Korean Hangul number string to ASCII number string.
"""
CharToNumLower_ko: 'uno.Enum'
"""
Transliterate a Korean Hanja lower case number string to ASCII number string.
"""
CharToNumLower_zh_CN: 'uno.Enum'
"""
Transliterate a Simplified Chinese lower case number string to ASCII number string.
"""
CharToNumLower_zh_TW: 'uno.Enum'
"""
Transliterate a Traditional Chinese lower case number string to ASCII number string.
"""
CharToNumUpper_ko: 'uno.Enum'
"""
Transliterate a Korean Hanja upper case number string to ASCII number string.
"""
CharToNumUpper_zh_CN: 'uno.Enum'
"""
Transliterate a Simplified Chinese upper case number string to ASCII number string.
"""
CharToNumUpper_zh_TW: 'uno.Enum'
"""
Transliterate a Traditional Chinese upper case number string to ASCII number string.
"""
END_OF_MODULE: 'uno.Enum'
"""
"""
FULLWIDTH_HALFWIDTH: 'uno.Enum'
"""
Transliterate a string from full width character to half width character.
"""
HALFWIDTH_FULLWIDTH: 'uno.Enum'
"""
Transliterate a string from half width character to full width character.
"""
HIRAGANA_KATAKANA: 'uno.Enum'
"""
Transliterate a Japanese string from Hiragana to Katakana.
"""
IGNORE_CASE: 'uno.Enum'
"""
Ignore case when comparing strings by transliteration service.
"""
IGNORE_KANA: 'uno.Enum'
"""
Ignore Hiragana and Katakana when comparing strings by transliteration service.
"""
IGNORE_WIDTH: 'uno.Enum'
"""
Ignore full width and half width character when comparing strings by transliteration service.

Ignore full width and half width characters when comparing strings by transliteration service.
"""
IgnoreBaFa_ja_JP: 'uno.Enum'
"""
Ignore Katakana and Hiragana Ba/Gua and Ha/Fa in Japanese fuzzy search.
"""
IgnoreHyuByu_ja_JP: 'uno.Enum'
"""
Ignore Katakana and Hiragana Hyu/Fyu and Byu/Gyu in Japanese fuzzy search.
"""
IgnoreIandEfollowedByYa_ja_JP: 'uno.Enum'
"""
Ignore Katakana YA/A which follows the character in either I or E row in Japanese fuzzy search.

Ignore Katakana YA/A following the character in either I or E row in Japanese fuzzy search.
"""
IgnoreIterationMark_ja_JP: 'uno.Enum'
"""
Ignore Hiragana and Katakana iteration mark in Japanese fuzzy search.
"""
IgnoreKiKuFollowedBySa_ja_JP: 'uno.Enum'
"""
Ignore Katakana KI/KU which follows the character in SA column in Japanese fuzzy search.

Ignore Katakana KI/KU following the character in SA column in Japanese fuzzy search.
"""
IgnoreMiddleDot_ja_JP: 'uno.Enum'
"""
Ignore middle dot in Japanese fuzzy search.
"""
IgnoreMinusSign_ja_JP: 'uno.Enum'
"""
Ignore dash or minus sign in Japanese fuzzy search.
"""
IgnoreProlongedSoundMark_ja_JP: 'uno.Enum'
"""
Ignore Japanese prolonged sound mark in Japanese fuzzy search.
"""
IgnoreSeZe_ja_JP: 'uno.Enum'
"""
Ignore Katakana and Hiragana Se/Sye and Ze/Je in Japanese fuzzy search.
"""
IgnoreSeparator_ja_JP: 'uno.Enum'
"""
Ignore separator punctuations in Japanese fuzzy search.
"""
IgnoreSize_ja_JP: 'uno.Enum'
"""
Ignore Japanese normal and small sized character in Japanese fuzzy search.
"""
IgnoreSpace_ja_JP: 'uno.Enum'
"""
Ignore white space characters, include space, TAB, return, etc. in Japanese fuzzy search.
"""
IgnoreTiJi_ja_JP: 'uno.Enum'
"""
Ignore Katakana and Hiragana Tsui/Tea/Ti and Dyi/Ji in Japanese fuzzy search.
"""
IgnoreTraditionalKana_ja_JP: 'uno.Enum'
"""
Ignore Japanese traditional Katakana and Hiragana character in Japanese fuzzy search.

Ignore Japanese traditional Katakana and Hiragana characters in Japanese fuzzy search.
"""
IgnoreTraditionalKanji_ja_JP: 'uno.Enum'
"""
Ignore Japanese traditional Kanji character in Japanese fuzzy search.

Ignore Japanese traditional Kanji characters in Japanese fuzzy search.
"""
IgnoreZiZu_ja_JP: 'uno.Enum'
"""
Ignore Katakana and Hiragana Zi/Zi and Zu/Zu in Japanese fuzzy search.
"""
KATAKANA_HIRAGANA: 'uno.Enum'
"""
Transliterate a Japanese string from Katakana to Hiragana.
"""
LOWERCASE_UPPERCASE: 'uno.Enum'
"""
Transliterate a string from lower case to upper case.
"""
LargeToSmall_ja_JP: 'uno.Enum'
"""
transliterate Japanese normal sized character to small sized character
"""
NumToCharFullwidth: 'uno.Enum'
"""
Transliterate a half width number string to full width number string.
"""
NumToCharHangul_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to Korean Hangul number string.
"""
NumToCharKanjiShort_ja_JP: 'uno.Enum'
"""
Transliterate an ASCII number string to Japanese Kanji number string.
"""
NumToCharLower_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to Korean Hanja lower case number string.
"""
NumToCharLower_zh_CN: 'uno.Enum'
"""
Transliterate an ASCII number string to Simplified Chinese lower case number string.
"""
NumToCharLower_zh_TW: 'uno.Enum'
"""
Transliterate an ASCII number string to Traditional Chinese lower case number string.
"""
NumToCharUpper_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to Korean Hanja upper case number string.
"""
NumToCharUpper_zh_CN: 'uno.Enum'
"""
Transliterate an ASCII number string to Simplified Chinese upper case number string.
"""
NumToCharUpper_zh_TW: 'uno.Enum'
"""
Transliterate an ASCII number string to Traditional Chinese upper case number string.
"""
NumToTextFormalHangul_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to formal Korean Hangul number string in spellout format.
"""
NumToTextFormalLower_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to formal Korean Hanja lower case number string in spellout format.
"""
NumToTextFormalUpper_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to formal Korean Hanja upper case number string in spellout format.
"""
NumToTextInformalHangul_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to informal Korean Hangul number string in spellout format.
"""
NumToTextInformalLower_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to informal Korean Hanja lower case number string in spellout format.
"""
NumToTextInformalUpper_ko: 'uno.Enum'
"""
Transliterate an ASCII number string to informal Korean Hanja upper case number string in spellout format.
"""
NumToTextLower_zh_CN: 'uno.Enum'
"""
Transliterate an ASCII number string to Simplified Chinese lower case number string in spellout format.
"""
NumToTextLower_zh_TW: 'uno.Enum'
"""
Transliterate an ASCII number string to Traditional Chinese lower case number string in spellout format.
"""
NumToTextUpper_zh_CN: 'uno.Enum'
"""
Transliterate an ASCII number string to Simplified Chinese upper case number string in spellout format.
"""
NumToTextUpper_zh_TW: 'uno.Enum'
"""
Transliterate an ASCII number string to Traditional Chinese upper case number string in spellout format.
"""
SmallToLarge_ja_JP: 'uno.Enum'
"""
transliterate Japanese small sized character to normal sized character
"""
TextToNumFormalHangul_ko: 'uno.Enum'
"""
Transliterate a Korean formal Hangul number string (spellout) to ASCII number string.
"""
TextToNumFormalLower_ko: 'uno.Enum'
"""
Transliterate a Korean formal Hanja lower case number string (spellout) to ASCII number string.
"""
TextToNumFormalUpper_ko: 'uno.Enum'
"""
Transliterate a Korean formal Hanja upper case number string (spellout) to ASCII number string.
"""
TextToNumInformalHangul_ko: 'uno.Enum'
"""
Transliterate a Korean informal Hangul number string (spellout) to ASCII number string.
"""
TextToNumInformalLower_ko: 'uno.Enum'
"""
Transliterate a Korean informal Hanja lower case number string (spellout) to ASCII number string.
"""
TextToNumInformalUpper_ko: 'uno.Enum'
"""
Transliterate a Korean informal Hanja upper case number string (spellout) to ASCII number string.
"""
TextToNumLower_zh_CN: 'uno.Enum'
"""
Transliterate a Simplified Chinese lower case number string (spellout) to ASCII number string.
"""
TextToNumLower_zh_TW: 'uno.Enum'
"""
Transliterate a Traditional Chinese lower case number string (spellout) to ASCII number string.
"""
TextToNumUpper_zh_CN: 'uno.Enum'
"""
Transliterate a Simplified Chinese upper case number string (spellout) to ASCII number string.
"""
TextToNumUpper_zh_TW: 'uno.Enum'
"""
Transliterate a Traditional Chinese upper case number string (spellout) to ASCII number string.
"""
UPPERCASE_LOWERCASE: 'uno.Enum'
"""
Transliterate a string from upper case to lower case.
"""

